@@ -2,6 +2,7 @@ use itertools::Itertools;
 use tombi_comment_directive::value::{TableCommonFormatRules, TableCommonLintRules};
 use tombi_comment_directive_serde::get_comment_directive_content;
 use tombi_future::{BoxFuture, Boxable};
+use tombi_schema_store::Accessor;
 use tombi_syntax::SyntaxElement;
 
 use crate::rule::root_table_keys_order;
@@ -10,7 +11,8 @@ use tombi_ast::AstToken;
 impl crate::Edit for tombi_ast::Root {
     fn edit<'a: 'b, 'b>(
         &'a self,
-        _accessors: &'a [tombi_schema_store::Accessor],
+        node: &'a tombi_document_tree::Value,
+        _accessors: &'a [Accessor],
         source_path: Option<&'a std::path::Path>,
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
@@ -20,11 +22,6 @@ impl crate::Edit for tombi_ast::Root {
             let mut key_values = vec![];
             let mut table_or_array_of_tables = vec![];
 
-            let comment_directive = get_comment_directive_content::<
-                TableCommonFormatRules,
-                TableCommonLintRules,
-            >(self.comment_directives());
-
             // Move document schema/tombi comment directive to the top.
             if self
                 .schema_document_comment_directive(source_path)
@@ -44,7 +41,13 @@ impl crate::Edit for tombi_ast::Root {
             for key_value in self.key_values() {
                 changes.extend(
                     key_value
-                        .edit(&[], source_path, current_schema, schema_context)
+                        .edit(
+                            node.into(),
+                            &[],
+                            source_path,
+                            current_schema,
+                            schema_context,
+                        )
                         .await,
                 );
                 key_values.push(key_value);
@@ -55,14 +58,14 @@ impl crate::Edit for tombi_ast::Root {
                     tombi_ast::TableOrArrayOfTable::Table(table) => {
                         changes.extend(
                             table
-                                .edit(&[], source_path, current_schema, schema_context)
+                                .edit(node, &[], source_path, current_schema, schema_context)
                                 .await,
                         );
                     }
                     tombi_ast::TableOrArrayOfTable::ArrayOfTable(array_of_table) => {
                         changes.extend(
                             array_of_table
-                                .edit(&[], source_path, current_schema, schema_context)
+                                .edit(node, &[], source_path, current_schema, schema_context)
                                 .await,
                         );
                     }
@@ -70,6 +73,11 @@ impl crate::Edit for tombi_ast::Root {
                 table_or_array_of_tables.push(table_or_array_of_table);
             }
 
+            let comment_directive = get_comment_directive_content::<
+                TableCommonFormatRules,
+                TableCommonLintRules,
+            >(self.comment_directives());
+
             changes.extend(
                 root_table_keys_order(
                     key_values,
