@@ -1,5 +1,4 @@
 use tombi_ast::AstNode;
-use tombi_schema_store::SchemaContext;
 use tombi_syntax::SyntaxElement;
 
 use crate::{change::Change, node::make_comma_with_trailing_comment};
@@ -7,7 +6,6 @@ use crate::{change::Change, node::make_comma_with_trailing_comment};
 pub fn array_comma_trailing_comment(
     value: &tombi_ast::Value,
     comma: Option<&tombi_ast::Comma>,
-    _schema_context: &SchemaContext,
 ) -> Vec<Change> {
     if let Some(trailing_comment) = value.trailing_comment() {
         if match comma {
