@@ -197,7 +197,7 @@ mod table_keys_order {
 
         test_format! {
             #[tokio::test]
-            async fn test_dependency_groups_multiple_lines_include_group_with_comment(
+            async fn test_dependency_groups_multiple_lines_include_group(
                 r#"
                 [project]
                 name = "tombi"
@@ -247,6 +247,48 @@ mod table_keys_order {
             )
         }
 
+        test_format! {
+            #[tokio::test]
+            async fn test_dependency_groups_multiple_lines_include_group_with_comment_directive_array_values_order_ascending(
+                r#"
+                [dependency-groups]
+                # tombi: format.rules.array-values-order = "ascending"
+                dev = [
+                  { include-group = "stub" },
+                  "pytest>=8.3.3",
+                  { include-group = "ci" },
+                  "ruff>=0.7.4",
+                ]
+                ci = [
+                  "ruff>=0.7.4",
+                  "pytest-ci>=0.0.0",
+                ]
+                stub = [
+                  "pytest-stub>=1.1.0",
+                ]
+                "#,
+                pyproject_schema_path(),
+            ) -> Ok(
+                r#"
+                [dependency-groups]
+                # tombi: format.rules.array-values-order = "ascending"
+                dev = [
+                  { include-group = "ci" },
+                  "pytest>=8.3.3",
+                  "ruff>=0.7.4",
+                  { include-group = "stub" },
+                ]
+                ci = [
+                  "pytest-ci>=0.0.0",
+                  "ruff>=0.7.4",
+                ]
+                stub = [
+                  "pytest-stub>=1.1.0",
+                ]
+                "#,
+            )
+        }
+
         test_format! {
             #[tokio::test]
             async fn test_tool_poetry_dependencies(
@@ -635,6 +677,61 @@ mod table_keys_order {
         }
     }
 
+    mod type_test {
+        use tombi_test_lib::type_test_schema_path;
+
+        use super::test_format;
+
+        test_format! {
+            #[tokio::test]
+            async fn test_array_sort(
+                r#"
+                [[array]]
+                integer = 1
+
+                [[array]]
+                integer = 2
+
+                [array.table]
+                key = "value"
+
+                [[array]]
+                integer = 3
+                "#,
+                type_test_schema_path(),
+            ) -> Ok(source)
+        }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_nested_array_sort(
+                r#"
+                [[array1]]
+                integer = 1
+
+                [[array1]]
+                integer = 2
+
+                [array1.table1]
+                key1 = "2"
+
+                [[array1.table1.array2]]
+                key2 = "1"
+
+                [[array1.table1.array2]]
+                key2 = "2"
+
+                [array1.table1.array2.table2]
+                key3 = "1"
+
+                [[array1]]
+                integer = 3
+                "#,
+                type_test_schema_path(),
+            ) -> Ok(source)
+        }
+    }
+
     mod non_schema {
         use super::test_format;
 
