@@ -90,8 +90,11 @@ impl ConfigManager {
     }
 
     /// Get config for a URI
-    pub async fn config_schema_store_for_uri(&self, uri: &tombi_uri::Uri) -> ConfigSchemaStore {
-        if let Ok(path) = uri.to_file_path() {
+    pub async fn config_schema_store_for_uri(
+        &self,
+        text_document_uri: &tombi_uri::Uri,
+    ) -> ConfigSchemaStore {
+        if let Ok(path) = text_document_uri.to_file_path() {
             self.config_schema_store_for_file(&path).await
         } else {
             self.default_config_schema_store().await
@@ -131,12 +134,12 @@ impl ConfigManager {
                         });
 
                     if schema_store.is_empty().await {
-                        tracing::info!("add new SchemaStore for {config_path_buf:?}");
+                        tracing::info!("Add new SchemaStore for {config_path_buf:?}");
                         if let Err(err) = schema_store
-                            .load_config(&config, Some(&config_path_buf))
+                            .load_config(config, Some(&config_path_buf))
                             .await
                         {
-                            tracing::error!("failed to load config: {err}");
+                            tracing::error!("Failed to load config: {err}");
                         }
 
                         for associated_schema in self.associated_schemas.read().await.iter() {
@@ -168,19 +171,18 @@ impl ConfigManager {
     pub async fn update_config_with_path(
         &self,
         config: Config,
-        config_path: PathBuf,
+        config_path: &Path,
     ) -> Result<(), tombi_schema_store::Error> {
         let schema_options = schema_store_options(&config, &self.backend_options);
 
         let mut config_schema_stores = self.config_schema_stores.write().await;
-        let config_schema_store =
-            config_schema_stores
-                .entry(config_path.clone())
-                .or_insert(ConfigSchemaStore::new(
-                    config.clone(),
-                    Some(config_path.clone()),
-                    SchemaStore::new_with_options(schema_options),
-                ));
+        let config_schema_store = config_schema_stores
+            .entry(config_path.to_owned())
+            .or_insert(ConfigSchemaStore::new(
+                config.clone(),
+                Some(config_path.to_owned()),
+                SchemaStore::new_with_options(schema_options),
+            ));
         config_schema_store
             .schema_store
             .reload_config(&config, Some(&config_path))
@@ -200,7 +202,7 @@ impl ConfigManager {
             let schema_store = SchemaStore::new_with_options(schema_options);
 
             if let Err(err) = schema_store.load_config(&config, None).await {
-                tracing::error!("failed to load default config: {err}");
+                tracing::error!("Failed to load default config: {err}");
             }
 
             for associated_schema in self.associated_schemas.read().await.iter() {
