@@ -790,6 +790,7 @@ mod completion_labels {
                 "tox",
                 "ty",
                 "uv",
+                "$tool_name",
             ]);
         }
 
@@ -988,6 +989,35 @@ mod completion_labels {
             ]);
         }
 
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_dependencies_and_next_section(
+                r#"
+                [dependencies]
+
+                [█]
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "badges",
+                "bench",
+                "bin",
+                "build-dependencies",
+                "dependencies",
+                "dev-dependencies",
+                "example",
+                "features",
+                "lib",
+                "lints",
+                "package",
+                "patch",
+                "profile",
+                "target",
+                "test",
+                "workspace",
+            ]);
+        }
+
         test_completion_labels! {
             #[tokio::test]
             async fn cargo_dependencies(
@@ -997,7 +1027,7 @@ mod completion_labels {
                 "#,
                 Schema(cargo_schema_path()),
             ) -> Ok([
-                "$key",
+                "$crate_name",
             ]);
         }
 
@@ -1189,6 +1219,20 @@ mod completion_labels {
                 "''",
             ]);
         }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_dependencies_patch(
+                r#"
+                [patch]
+                █
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "crates-io",
+                "$source_url_or_registry_name"
+            ]);
+        }
     }
 
     mod untagged_union {
