@@ -1,3 +1,5 @@
+use itertools::Itertools;
+
 use super::SchemaAccessor;
 
 pub struct SchemaContext<'a> {
@@ -20,12 +22,9 @@ impl SchemaContext<'_> {
         current_schema: Option<&crate::CurrentSchema<'_>>,
     ) -> Option<Result<crate::DocumentSchema, crate::Error>> {
         if let Some(sub_schema_uri_map) = self.sub_schema_uri_map {
-            if let Some(sub_schema_uri) = sub_schema_uri_map.get(
-                &accessors
-                    .iter()
-                    .map(SchemaAccessor::from)
-                    .collect::<Vec<_>>(),
-            ) {
+            if let Some(sub_schema_uri) =
+                sub_schema_uri_map.get(&accessors.iter().map(SchemaAccessor::from).collect_vec())
+            {
                 if current_schema
                     .is_none_or(|current_schema| &*current_schema.schema_uri != sub_schema_uri)
                 {
