@@ -20,16 +20,8 @@ impl Validate for tombi_document_tree::Array {
         accessors: &'a [tombi_schema_store::Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> BoxFuture<'b, Result<(), Vec<tombi_diagnostic::Diagnostic>>> {
+    ) -> BoxFuture<'b, Result<(), crate::Error>> {
         async move {
-            let mut total_diagnostics = vec![];
-            let (value_rules, diagnostics) =
-                get_tombi_array_comment_directive_and_diagnostics(self, accessors).await;
-
-            if !diagnostics.is_empty() {
-                total_diagnostics.extend(diagnostics);
-            }
-
             if let Some(Ok(DocumentSchema {
                 value_schema: Some(value_schema),
                 schema_uri,
@@ -52,8 +44,11 @@ impl Validate for tombi_document_tree::Array {
                     .await;
             }
 
-            if let Some(current_schema) = current_schema {
-                let result = match current_schema.value_schema.as_ref() {
+            let (lint_rules, lint_rules_diagnostics) =
+                get_tombi_array_comment_directive_and_diagnostics(self, accessors).await;
+
+            let result = if let Some(current_schema) = current_schema {
+                match current_schema.value_schema.as_ref() {
                     ValueSchema::Array(array_schema) => {
                         validate_array(
                             self,
@@ -61,7 +56,7 @@ impl Validate for tombi_document_tree::Array {
                             array_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref(),
+                            lint_rules.as_ref(),
                         )
                         .await
                     }
@@ -72,7 +67,7 @@ impl Validate for tombi_document_tree::Array {
                             one_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -83,7 +78,7 @@ impl Validate for tombi_document_tree::Array {
                             any_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -94,7 +89,7 @@ impl Validate for tombi_document_tree::Array {
                             all_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -103,25 +98,25 @@ impl Validate for tombi_document_tree::Array {
                         value_schema.value_type().await,
                         self.value_type(),
                         self.range(),
-                        value_rules.as_ref().map(|rules| &rules.common),
+                        lint_rules.as_ref().map(|rules| &rules.common),
                     ),
-                };
-
-                if let Err(diagnostics) = result {
-                    total_diagnostics.extend(diagnostics);
                 }
             } else {
-                if let Err(diagnostics) =
-                    validate_array_without_schema(self, accessors, schema_context).await
-                {
-                    total_diagnostics.extend(diagnostics);
-                }
-            }
+                validate_array_without_schema(self, accessors, schema_context).await
+            };
 
-            if total_diagnostics.is_empty() {
-                Ok(())
-            } else {
-                Err(total_diagnostics)
+            match result {
+                Ok(()) => {
+                    if lint_rules_diagnostics.is_empty() {
+                        Ok(())
+                    } else {
+                        Err(lint_rules_diagnostics.into())
+                    }
+                }
+                Err(mut error) => {
+                    error.prepend_diagnostics(lint_rules_diagnostics);
+                    Err(error)
+                }
             }
         }
         .boxed()
@@ -134,9 +129,9 @@ async fn validate_array(
     array_schema: &tombi_schema_store::ArraySchema,
     current_schema: &CurrentSchema<'_>,
     schema_context: &tombi_schema_store::SchemaContext<'_>,
-    value_rules: Option<&ArrayCommonLintRules>,
-) -> Result<(), Vec<tombi_diagnostic::Diagnostic>> {
-    let mut diagnostics = vec![];
+    lint_rules: Option<&ArrayCommonLintRules>,
+) -> Result<(), crate::Error> {
+    let mut total_diagnostics = vec![];
 
     if let Some(items) = &array_schema.items {
         let mut referable_schema = items.write().await;
@@ -156,11 +151,11 @@ async fn validate_array(
                     .chain(std::iter::once(tombi_schema_store::Accessor::Index(index)))
                     .collect_vec();
 
-                if let Err(schema_diagnostics) = value
+                if let Err(crate::Error { diagnostics, .. }) = value
                     .validate(&new_accessors, Some(&current_schema), schema_context)
                     .await
                 {
-                    diagnostics.extend(schema_diagnostics);
+                    total_diagnostics.extend(diagnostics);
                 }
             }
         }
@@ -168,7 +163,7 @@ async fn validate_array(
 
     if let Some(max_items) = array_schema.max_items {
         if array_value.values().len() > max_items {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.value)
                 .and_then(|rules| {
                     rules
@@ -185,13 +180,13 @@ async fn validate_array(
                 }),
                 range: array_value.range(),
             }
-            .push_diagnostic_with_level(level, &mut diagnostics);
+            .push_diagnostic_with_level(level, &mut total_diagnostics);
         }
     }
 
     if let Some(min_items) = array_schema.min_items {
         if array_value.values().len() < min_items {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.value)
                 .and_then(|rules| {
                     rules
@@ -208,12 +203,12 @@ async fn validate_array(
                 }),
                 range: array_value.range(),
             }
-            .push_diagnostic_with_level(level, &mut diagnostics);
+            .push_diagnostic_with_level(level, &mut total_diagnostics);
         }
     }
 
     if array_schema.unique_items == Some(true) {
-        let level = value_rules
+        let level = lint_rules
             .map(|rules| &rules.value)
             .and_then(|rules| {
                 rules
@@ -241,15 +236,15 @@ async fn validate_array(
                         kind: Box::new(crate::DiagnosticKind::ArrayUniqueValues),
                         range: value.range(),
                     }
-                    .push_diagnostic_with_level(level, &mut diagnostics);
+                    .push_diagnostic_with_level(level, &mut total_diagnostics);
                 }
             }
         }
     }
 
-    if diagnostics.is_empty() {
+    if total_diagnostics.is_empty() {
         if array_schema.deprecated == Some(true) {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -265,14 +260,14 @@ async fn validate_array(
                 )),
                 range: array_value.range(),
             }
-            .push_diagnostic_with_level(level, &mut diagnostics);
+            .push_diagnostic_with_level(level, &mut total_diagnostics);
         }
     }
 
-    if diagnostics.is_empty() {
+    if total_diagnostics.is_empty() {
         Ok(())
     } else {
-        Err(diagnostics)
+        Err(total_diagnostics.into())
     }
 }
 
@@ -280,12 +275,12 @@ async fn validate_array_without_schema(
     array_value: &tombi_document_tree::Array,
     accessors: &[tombi_schema_store::Accessor],
     schema_context: &tombi_schema_store::SchemaContext<'_>,
-) -> Result<(), Vec<tombi_diagnostic::Diagnostic>> {
-    let mut diagnostics = vec![];
+) -> Result<(), crate::Error> {
+    let mut total_diagnostics = vec![];
 
     // Validate without schema
     for (index, value) in array_value.values().iter().enumerate() {
-        if let Err(value_diagnostics) = value
+        if let Err(crate::Error { diagnostics, .. }) = value
             .validate(
                 &accessors
                     .iter()
@@ -297,13 +292,13 @@ async fn validate_array_without_schema(
             )
             .await
         {
-            diagnostics.extend(value_diagnostics);
+            total_diagnostics.extend(diagnostics);
         }
     }
 
-    if diagnostics.is_empty() {
+    if total_diagnostics.is_empty() {
         Ok(())
     } else {
-        Err(diagnostics)
+        Err(total_diagnostics.into())
     }
 }
