@@ -16,28 +16,23 @@ impl Validate for tombi_document_tree::Boolean {
         accessors: &'a [tombi_schema_store::Accessor],
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> BoxFuture<'b, Result<(), Vec<tombi_diagnostic::Diagnostic>>> {
+    ) -> BoxFuture<'b, Result<(), crate::Error>> {
         async move {
-            let mut total_diagnostics = vec![];
-            let value_rules = if let Some(comment_directives) = self.comment_directives() {
-                let (value_rules, diagnostics) = get_tombi_key_table_value_rules_and_diagnostics::<
-                    BooleanCommonFormatRules,
-                    BooleanCommonLintRules,
-                >(comment_directives, accessors)
-                .await;
+            let (lint_rules, lint_rules_diagnostics) =
+                if let Some(comment_directives) = self.comment_directives() {
+                    get_tombi_key_table_value_rules_and_diagnostics::<
+                        BooleanCommonFormatRules,
+                        BooleanCommonLintRules,
+                    >(comment_directives, accessors)
+                    .await
+                } else {
+                    (None, Vec::with_capacity(0))
+                };
 
-                total_diagnostics.extend(diagnostics);
-
-                value_rules
-            } else {
-                None
-            };
-
-            if let Some(current_schema) = current_schema {
-                let result = match current_schema.value_schema.as_ref() {
+            let result = if let Some(current_schema) = current_schema {
+                match current_schema.value_schema.as_ref() {
                     ValueSchema::Boolean(boolean_schema) => {
-                        validate_boolean(self, accessors, boolean_schema, value_rules.as_ref())
-                            .await
+                        validate_boolean(self, accessors, boolean_schema, lint_rules.as_ref()).await
                     }
                     ValueSchema::OneOf(one_of_schema) => {
                         validate_one_of(
@@ -46,7 +41,7 @@ impl Validate for tombi_document_tree::Boolean {
                             one_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -57,7 +52,7 @@ impl Validate for tombi_document_tree::Boolean {
                             any_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -68,7 +63,7 @@ impl Validate for tombi_document_tree::Boolean {
                             all_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -77,19 +72,25 @@ impl Validate for tombi_document_tree::Boolean {
                         value_schema.value_type().await,
                         self.value_type(),
                         self.range(),
-                        value_rules.as_ref().map(|rules| &rules.common),
+                        lint_rules.as_ref().map(|rules| &rules.common),
                     ),
-                };
-
-                if let Err(diagnostics) = result {
-                    total_diagnostics.extend(diagnostics);
                 }
-            }
-
-            if total_diagnostics.is_empty() {
-                Ok(())
             } else {
-                Err(total_diagnostics)
+                Ok(())
+            };
+
+            match result {
+                Ok(()) => {
+                    if lint_rules_diagnostics.is_empty() {
+                        Ok(())
+                    } else {
+                        Err(lint_rules_diagnostics.into())
+                    }
+                }
+                Err(mut error) => {
+                    error.prepend_diagnostics(lint_rules_diagnostics);
+                    Err(error)
+                }
             }
         }
         .boxed()
@@ -100,8 +101,8 @@ async fn validate_boolean(
     boolean_value: &tombi_document_tree::Boolean,
     accessors: &[tombi_schema_store::Accessor],
     boolean_schema: &tombi_schema_store::BooleanSchema,
-    value_rules: Option<&BooleanCommonLintRules>,
-) -> Result<(), Vec<tombi_diagnostic::Diagnostic>> {
+    lint_rules: Option<&BooleanCommonLintRules>,
+) -> Result<(), crate::Error> {
     let mut diagnostics = vec![];
 
     let value = boolean_value.value();
@@ -109,7 +110,7 @@ async fn validate_boolean(
 
     if let Some(const_value) = &boolean_schema.const_value {
         if value != *const_value {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -132,7 +133,7 @@ async fn validate_boolean(
 
     if let Some(enumerate) = &boolean_schema.enumerate {
         if !enumerate.contains(&value) {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -155,7 +156,7 @@ async fn validate_boolean(
 
     if diagnostics.is_empty() {
         if boolean_schema.deprecated == Some(true) {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -179,6 +180,6 @@ async fn validate_boolean(
     if diagnostics.is_empty() {
         Ok(())
     } else {
-        Err(diagnostics)
+        Err(diagnostics.into())
     }
 }
