@@ -19,28 +19,23 @@ impl Validate for tombi_document_tree::String {
         accessors: &'a [tombi_schema_store::Accessor],
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> BoxFuture<'b, Result<(), Vec<tombi_diagnostic::Diagnostic>>> {
+    ) -> BoxFuture<'b, Result<(), crate::Error>> {
         async move {
-            let mut total_diagnostics = vec![];
+            let (lint_rules, lint_rules_diagnostics) =
+                if let Some(comment_directives) = self.comment_directives() {
+                    get_tombi_key_table_value_rules_and_diagnostics::<
+                        StringCommonFormatRules,
+                        StringCommonLintRules,
+                    >(comment_directives, accessors)
+                    .await
+                } else {
+                    (None, Vec::with_capacity(0))
+                };
 
-            let value_rules = if let Some(comment_directives) = self.comment_directives() {
-                let (value_rules, diagnostics) = get_tombi_key_table_value_rules_and_diagnostics::<
-                    StringCommonFormatRules,
-                    StringCommonLintRules,
-                >(comment_directives, accessors)
-                .await;
-
-                total_diagnostics.extend(diagnostics);
-
-                value_rules
-            } else {
-                None
-            };
-
-            if let Some(current_schema) = current_schema {
-                let result = match current_schema.value_schema.as_ref() {
+            let result = if let Some(current_schema) = current_schema {
+                match current_schema.value_schema.as_ref() {
                     ValueSchema::String(string_schema) => {
-                        validate_string(self, accessors, string_schema, value_rules.as_ref()).await
+                        validate_string(self, accessors, string_schema, lint_rules.as_ref()).await
                     }
                     ValueSchema::OneOf(one_of_schema) => {
                         validate_one_of(
@@ -49,7 +44,7 @@ impl Validate for tombi_document_tree::String {
                             one_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -60,7 +55,7 @@ impl Validate for tombi_document_tree::String {
                             any_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -71,7 +66,7 @@ impl Validate for tombi_document_tree::String {
                             all_of_schema,
                             current_schema,
                             schema_context,
-                            value_rules.as_ref().map(|rules| &rules.common),
+                            lint_rules.as_ref().map(|rules| &rules.common),
                         )
                         .await
                     }
@@ -80,19 +75,25 @@ impl Validate for tombi_document_tree::String {
                         value_schema.value_type().await,
                         self.value_type(),
                         self.range(),
-                        value_rules.as_ref().map(|rules| &rules.common),
+                        lint_rules.as_ref().map(|rules| &rules.common),
                     ),
-                };
-
-                if let Err(diagnostics) = result {
-                    total_diagnostics.extend(diagnostics);
                 }
-            }
-
-            if total_diagnostics.is_empty() {
-                Ok(())
             } else {
-                Err(total_diagnostics)
+                Ok(())
+            };
+
+            match result {
+                Ok(()) => {
+                    if lint_rules_diagnostics.is_empty() {
+                        Ok(())
+                    } else {
+                        Err(lint_rules_diagnostics.into())
+                    }
+                }
+                Err(mut error) => {
+                    error.prepend_diagnostics(lint_rules_diagnostics);
+                    Err(error)
+                }
             }
         }
         .boxed()
@@ -103,15 +104,15 @@ async fn validate_string(
     string_value: &tombi_document_tree::String,
     accessors: &[tombi_schema_store::Accessor],
     string_schema: &tombi_schema_store::StringSchema,
-    value_rules: Option<&StringCommonLintRules>,
-) -> Result<(), Vec<tombi_diagnostic::Diagnostic>> {
+    lint_rules: Option<&StringCommonLintRules>,
+) -> Result<(), crate::Error> {
     let mut diagnostics = vec![];
     let value = string_value.value().to_string();
     let range = string_value.range();
 
     if let Some(const_value) = &string_schema.const_value {
         if value != *const_value {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -134,7 +135,7 @@ async fn validate_string(
 
     if let Some(enumerate) = &string_schema.enumerate {
         if !enumerate.contains(&value) {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -157,7 +158,7 @@ async fn validate_string(
 
     if let Some(max_length) = &string_schema.max_length {
         if value.len() > *max_length {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.value)
                 .and_then(|rules| {
                     rules
@@ -180,7 +181,7 @@ async fn validate_string(
 
     if let Some(min_length) = &string_schema.min_length {
         if value.len() < *min_length {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.value)
                 .and_then(|rules| {
                     rules
@@ -204,7 +205,7 @@ async fn validate_string(
         match format {
             StringFormat::Email => {
                 if !format::email::validate_format(&value) {
-                    let level = value_rules
+                    let level = lint_rules
                         .map(|rules| &rules.value)
                         .and_then(|rules| {
                             rules
@@ -226,7 +227,7 @@ async fn validate_string(
             }
             StringFormat::Hostname => {
                 if !format::hostname::validate_format(&value) {
-                    let level = value_rules
+                    let level = lint_rules
                         .map(|rules| &rules.value)
                         .and_then(|rules| {
                             rules
@@ -248,7 +249,7 @@ async fn validate_string(
             }
             StringFormat::Uri => {
                 if !format::uri::validate_format(&value) {
-                    let level = value_rules
+                    let level = lint_rules
                         .map(|rules| &rules.value)
                         .and_then(|rules| {
                             rules
@@ -270,7 +271,7 @@ async fn validate_string(
             }
             StringFormat::Uuid => {
                 if !format::uuid::validate_format(&value) {
-                    let level = value_rules
+                    let level = lint_rules
                         .map(|rules| &rules.value)
                         .and_then(|rules| {
                             rules
@@ -296,7 +297,7 @@ async fn validate_string(
     if let Some(pattern) = &string_schema.pattern {
         if let Ok(regex) = Regex::new(pattern) {
             if !regex.is_match(&value) {
-                let level = value_rules
+                let level = lint_rules
                     .map(|rules| &rules.value)
                     .and_then(|rules| {
                         rules
@@ -322,7 +323,7 @@ async fn validate_string(
 
     if diagnostics.is_empty() {
         if string_schema.deprecated == Some(true) {
-            let level = value_rules
+            let level = lint_rules
                 .map(|rules| &rules.common)
                 .and_then(|rules| {
                     rules
@@ -346,6 +347,6 @@ async fn validate_string(
     if diagnostics.is_empty() {
         Ok(())
     } else {
-        Err(diagnostics)
+        Err(diagnostics.into())
     }
 }
